Usage
l.diag (nn)
u.diag (nn)
ordinal.maker (vec, cuts=quantile(vec, c(0.25, 0.5, 0.75))) unwrap.CID.Gibbs (gibbs.out)
mat.cov.to.edge.list.cov (Xmat, n.nodes = dim(Xmat)[1],
arc.list = make.arc.list(n.nodes))
Arguments
nn
The number of rows in the square matrix for which we wish to
extract the lower or upper diagonal matrix.
vec
The elements to be divided into ordinal categories.
cuts
The cut points at which to divide vec into ordinal
categories. Default values separate vec into quartiles.
gibbs.out
The list object of draws from the Gibbs sampler. This
re-sorts the object into a matrix form for easier consumption.
Xmat
A three-dimensional array of covariates, with n.nodes rows
and columns. Each slice is a different covariate.
n.nodes
Number of nodes in network
arc.list
List of potential edges in network.