Learn R Programming

CIDnetworks (version 0.2.5)

CIDnetworks-package: Model Complex Networks With Multiple Components

Description

The CIDnetworks package allows a user to construct hierarchical models of complex networks using one of many different modes for latent structure.

Arguments

Details

ll{ Package: CIDnetworks Type: Package Version: 0.1 Date: 2014-01-20 License: GPLv3 }

References

Forthcoming.

Examples

Run this code
data(dolphins)
  model.plain <- CID.Gibbs (edge.list=dolphins, burnin=10, draws=10)

Run the code above in your browser using DataLab