Usage
CID.Gibbs (edge.list,
outcome,
sociomatrix, CID.object,
components=list(),
class.outcome=NULL,
fill.in.missing.edges=missing(outcome),
...)
unwrap.CID.Gibbs (gibbs.out)
## S3 method for class 'CID.Gibbs':
print(x, \dots)
## S3 method for class 'CID.Gibbs':
summary(object, \dots)
## S3 method for class 'CID.Gibbs':
plot(x, \dots)
network.plot (x, fitted.values=FALSE, ...)
sociogram.plot (x, component.color=0, ...)
Arguments
edge.list
A list of (potential) edges present in the network.
outcome
The outcome on each of these edges.
sociomatrix
If preferred, a sociomatrix of edges and
values. The lower triangle will be taken in.
CID.object
If desired, an existing CID object can be loaded
instead of a new network specification.
components
A list of sub-components, including (COV, HBM, LSM,
LVM, MMSBM, SBM, SR).
class.outcome
One of "ordinal" (default, values from 0 to
higher integers), "binary" (ordinal in 0 and 1) or "gaussian"
(unbounded continuous values). Class is auto-detected if NULL remains
in place.
fill.in.missing.edges
If TRUE, the edge list will be augmented
with zeroes for all unspecified but possible edges. By default, if an
outcome is specified, these edges will not be added.
...
Further arguments to be passed to the Gibbs sampler
routine. See details for more.
gibbs.out
The list object of draws from the Gibbs sampler. This
re-sorts the object into a matrix form for easier consumption.
x, object
An object outputted from CID.Gibbs.
fitted.values
If TRUE, plots the fitted tie strength under the
Gibbs sampler. If FALSE, plots the network outcomes as entered.
component.color
If non-zero, colors the nodes in the sociogram
according to the output of the Gibbs sampler.